(self.webpackChunksimpel_pages=self.webpackChunksimpel_pages||[]).push([["main"],{"./source/images.js":function(){eval("\n\n//# sourceURL=webpack://simpel_pages/./source/images.js?")},"./source/main.js":function(__unused_webpack_module,__webpack_exports__,__webpack_require__){"use strict";eval('__webpack_require__.r(__webpack_exports__);\n/* harmony import */ var _images__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ./images */ "./source/images.js");\n/* harmony import */ var _images__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_images__WEBPACK_IMPORTED_MODULE_0__);\n/* harmony import */ var _scss_main_scss__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ./scss/main.scss */ "./source/scss/main.scss");\n\n\ndocument.addEventListener("DOMContentLoaded", function () {\n  console.log("Greeting from Simpel Pages");\n});\n\n//# sourceURL=webpack://simpel_pages/./source/main.js?')},"./source/scss/main.scss":function(__unused_webpack_module,__webpack_exports__,__webpack_require__){"use strict";eval("__webpack_require__.r(__webpack_exports__);\n// extracted by mini-css-extract-plugin\n\n\n//# sourceURL=webpack://simpel_pages/./source/scss/main.scss?")}},function(_){_.O(0,["shared"],(function(){return e="./source/main.js",_(_.s=e);var e}));_.O()}]);